@@ -29,22 +29,26 @@
 #include <KLocale>
 
 #include <QtGui/QLabel>
+#include <QPainter>
+#include <QtCore/QDebug>
+
+#include <math.h>
 
 
 ProgressBox::ProgressBox(QWidget *parent, QObject *part, Filelight::ScanManager *m)
-        : QLabel(parent)
+        : QWidget(parent)
         , m_manager(m)
 {
     hide();
 
     setObjectName(QLatin1String( "ProgressBox" ));
 
-    setAlignment(Qt::AlignCenter);
     setFont(KGlobalSettings::fixedFont());
     setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Fixed);
 
     setText(999999);
-    setMinimumWidth(sizeHint().width());
+    setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
+    setMinimumSize(200, 200);
 
     connect(&m_timer, SIGNAL(timeout()), SLOT(report()));
     connect(part, SIGNAL(started(KIO::Job*)), SLOT(start()));
@@ -64,6 +68,7 @@ void
 ProgressBox::report() //slot
 {
     setText(m_manager->files());
+    repaint();
 }
 
 void
@@ -83,7 +88,41 @@ ProgressBox::halt()
 void
 ProgressBox::setText(int files)
 {
-    QLabel::setText(i18np("%1 File", "%1 Files", files));
+    m_text = i18np("%1 File", "%1 Files", files);
+    m_textWidth = fontMetrics().width(m_text);
+    m_textHeight = fontMetrics().height();
 }
 
+static const int pieces = 4;
+static const float angleFactor[] = { -0.75, 0.5, 1.0, -0.3 };
+static const int length[] = { 30, 40, 50, 60 };
+static const int angleOffset[] = { 5760, 0, 0, -5760 };
+static const int aLength[] = { 300, 2000, 200, 2000 };
+
+void ProgressBox::paintEvent(QPaintEvent*)
+{
+    QPainter paint(this);
+    paint.setRenderHint(QPainter::Antialiasing);
+    static int tick = 0;
+    tick+=16;
+    
+    for (int i=0; i<pieces; i++) {
+        const QRect rect(length[i]/2, length[i]/2, 200- length[i], 200-length[i]);
+        int angle = angleFactor[i] + tick*angleFactor[i];
+        QRadialGradient gradient(rect.center(), sin(angle/160.0f) * 100);
+        gradient.setColorAt(0, QColor::fromHsv(abs(angle/16) % 360 , 160, 255));
+        gradient.setColorAt(1, QColor::fromHsv(abs(angle/16) % 360 , 160, 128));
+        QBrush brush(gradient);
+        paint.setBrush(brush);
+        paint.drawPie(QRect(rect), angle, aLength[i]);
+    }
+    
+    paint.setBrush(QColor(255,255,255,200));
+    paint.translate(0.5, 0.5);
+    paint.drawRoundedRect(95-m_textWidth/2, 85, m_textWidth+10, m_textHeight+10, 5, 5);
+    paint.translate(-0.5, -0.5);
+    paint.drawText(100 - m_textWidth/2, 100, m_text);
+}
+
+
 #include "progressBox.moc"
